@@ -92,7 +92,7 @@ process_layers <- function(g, z, gt, gf, interactive) {
 	
 	
 	# fill info
-	if (is.null(g$tm_fil)) {
+	if (is.null(g$tm_fill)) {
 		gfill <- list(fill=NULL, xfill=NA, fill.legend.title=NA, fill.id=NA) 
 	} else {
 		gfill <- process_fill(data, g$tm_fill, gborders, gt, gf, z=z+which(plot.order=="tm_fill"), interactive=interactive)
@@ -146,4 +146,4 @@ process_layers <- function(g, z, gt, gf, interactive) {
 	plot.order <- plot.order[substr(plot.order, 1, 13)!="tm_add_legend"]
 	
 	c(list(npol=nrow(data), varnames=list(by=by, fill=gfill$xfill, symbol.size=gsymbol$xsize, symbol.col=gsymbol$xcol, symbol.shape=gsymbol$xshape, line.col=glines$xline, line.lwd=glines$xlinelwd, raster=graster$xraster, text.size=gtext$xtsize, text.col=gtext$xtcol), idnames=list(fill=gfill$fill.id, symbol=gsymbol$symbol.id, line=glines$line.id), data_by=data$GROUP_BY, nrow=nrow, ncol=ncol, panel.names=panel.names, plot.order=plot.order, any.legend=any.legend), gborders, gfill, glines, gsymbol, gtext, graster, list(add_legends=add_legends))
-}
\ No newline at end of file
+}
